@@ -1,6 +1,6 @@
 
-import { locale as appLocale } from '../../intl'
-import { localeCompare } from '../../helpers'
+import { locale as appLocale } from '_/intl'
+import { localeCompare } from '_/helpers'
 
 /*
  * Sort an Immutable List of Maps (set of disks) for display on the VmDisks list.
